from mosamatic2.core.pipelines.defaultpipeline.defaultpipeline import DefaultPipeline
from mosamatic2.core.pipelines.defaultdockerpipeline.defaultdockerpipeline import DefaultDockerPipeline
from mosamatic2.core.pipelines.boadockerpipeline.boadockerpipeline import BoaDockerPipeline